Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(792)

Unified Diff: chrome/browser/chromeos/gdata/gdata_util.h

Issue 10877006: Rename GDataErrorCode to DriveErrorCode, GDataFileError to DriveFileError (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/gdata_util.h
diff --git a/chrome/browser/chromeos/gdata/gdata_util.h b/chrome/browser/chromeos/gdata/gdata_util.h
index 43cd146c35f73e38b55d0bdda30321a21a5f8ff0..809abe52c9bae7eb7e4588de0fb29feac14d21a3 100644
--- a/chrome/browser/chromeos/gdata/gdata_util.h
+++ b/chrome/browser/chromeos/gdata/gdata_util.h
@@ -13,7 +13,7 @@
#include "base/memory/scoped_ptr.h"
#include "base/platform_file.h"
#include "base/time.h"
-#include "chrome/browser/chromeos/gdata/gdata_errorcode.h"
+#include "chrome/browser/chromeos/gdata/drive_errorcode.h"
#include "googleurl/src/gurl.h"
class FilePath;
@@ -108,8 +108,8 @@ void ParseCacheFilePath(const FilePath& path,
// Returns true if Drive v2 API is enabled via commandline switch.
bool IsDriveV2ApiEnabled();
-// Returns a PlatformFileError that corresponds to the GDataFileError provided.
-base::PlatformFileError GDataFileErrorToPlatformError(GDataFileError error);
+// Returns a PlatformFileError that corresponds to the DriveFileError provided.
+base::PlatformFileError DriveFileErrorToPlatformError(DriveFileError error);
// Parses an RFC 3339 date/time into a base::Time, returning true on success.
// The time string must be in the format "yyyy-mm-ddThh:mm:ss.dddTZ" (TZ is
@@ -122,7 +122,7 @@ std::string FormatTimeAsString(const base::Time& time);
std::string FormatTimeAsStringLocaltime(const base::Time& time);
// Callback type for PrepareWritableFilePathAndRun.
-typedef base::Callback<void (GDataFileError, const FilePath& path)>
+typedef base::Callback<void (DriveFileError, const FilePath& path)>
OpenFileCallback;
// Invokes |callback| on blocking thread pool, after converting virtual |path|
@@ -138,7 +138,7 @@ void PrepareWritableFileAndRun(Profile* profile,
const OpenFileCallback& callback);
// Converts gdata error code into file platform error code.
-GDataFileError GDataToGDataFileError(GDataErrorCode status);
+DriveFileError DriveToDriveFileError(DriveErrorCode status);
// Wrapper around BrowserThread::PostTask to post a task to the blocking
// pool with the given sequence token.

Powered by Google App Engine
This is Rietveld 408576698